@@ -1,9 +1,11 @@
 # advanced cat which correctly handles ini-like lines and short line widths.
-wcat = function(header, value) {
+wcat = function(header, value, indent = 2) {
 
   # get the number of available columns.
   columns = options("width")
 
+  header = sprintf("%-40s", paste0(strrep(" ", indent), header, ":"))
+
   # blatantly ignore any line width shorter than 45, trying to support
   # that case is a losing proposition.
   if ((columns >= nchar(header) + nchar(value) + 1) || (columns < 45)) {
@@ -23,20 +25,20 @@ wcat = function(header, value) {
 }#WCAT
 
 # advanced cat handles model strings and short line widths.
-fcat = function(modelstr) {
+fcat = function(modelstr, indent = 0) {
 
   # measure the number of available columns.
   columns = options("width")
 
   if ((columns >= nchar(modelstr)) || columns < 45) {
 
-    cat("  ", modelstr, "\n")
+    cat(strrep(" ", indent), modelstr, "\n")
 
   }#THEN
   else {
 
     cat(paste(strsplit(modelstr, "\\]")[[1]], "]", sep = ""),
-      fill = TRUE, sep = "", labels = "  ")
+      fill = TRUE, sep = "", labels = strrep(" ", indent))
 
   }#ELSE
 
